import { version } from '../package.json';
import resolve from '@rollup/plugin-node-resolve';
import typescript from '@rollup/plugin-typescript';
import commonjs from '@rollup/plugin-commonjs';
import babel from '@rollup/plugin-babel';
import terser from '@rollup/plugin-terser';
import dts from 'rollup-plugin-dts';
import replace from 'rollup-plugin-replace';

export default [
  {
    input: './src/index.ts',
    output: {
      file: './dist/index.js',
      format: 'esm',
      // sourcemap: true,
    },
    plugins: [
      resolve({
        extensions: ['.js', '.jsx', '.ts', '.tsx', '.mjs', '.cjs'],
        preferBuiltins: false,
        // 专门处理react-native模块
        dedupe: ['react-native'],
      }),
      commonjs({
        transformMixedEsModules: true,
        include: /node_modules/,
        // 强制转换ES模块
        requireReturnsDefault: 'auto',
        // 包含所有可能的扩展名
        extensions: ['.js', '.jsx', '.ts', '.tsx', '.mjs', '.cjs']
      }),
      babel({
        babelHelpers: 'bundled',
        exclude: 'node_modules/**',
      }),
      typescript(),
      replace({ BUNDLE_VERSION: version }),
      terser(),
    ],
    external: ['@tencentcloud/chat-react-native', 'react-native-create-thumbnail']
  },
  {
    // 生成 .d.ts 类型声明文件
    input: './src/index.ts',
    output: {
      file: './dist/index.d.ts',
      format: 'es',
    },
    plugins: [dts()],
  },
];