"use strict";
exports.__esModule = true;
var EventCenter = /** @class */ (function () {
    function EventCenter(ChatEngine) {
        if (!EventCenter.instance) {
            EventCenter.instance = this;
            this.engine = ChatEngine;
            this.events = {};
            this.bindIMEvents();
        }
        return EventCenter.instance;
    }
    EventCenter.prototype.addEvent = function (event, callback) {
        if (this.events[event]) {
            this.events[event].set(callback, 1);
        }
        else {
            this.events[event] = new Map();
            this.events[event].set(callback, 1);
        }
    };
    EventCenter.prototype.removeEvents = function () {
        var _this = this;
        Object.keys(this.events).forEach(function (event) {
            _this.events[event].clear();
        });
        this.events = {};
    };
    EventCenter.prototype.dispatch = function (event, data) {
        if (!this.events[event]) {
            return;
        }
        for (var _i = 0, _a = this.events[event].keys(); _i < _a.length; _i++) {
            var callback = _a[_i];
            callback.call(this, data);
        }
    };
    EventCenter.prototype.bindIMEvents = function () {
        this.engine.chat.on(this.engine.EVENT.SDK_READY, this.onSDKReady, this);
        this.engine.chat.on(this.engine.EVENT.SDK_NOT_READY, this.onSDKNotReady, this);
        this.engine.chat.on(this.engine.EVENT.KICKED_OUT, this.onKickedOut, this);
        this.engine.chat.on(this.engine.EVENT.NET_STATE_CHANGE, this.onNetStateChange, this);
        this.engine.chat.on(this.engine.EVENT.MESSAGE_RECEIVED, this.onReceiveMessage, this);
        this.engine.chat.on(this.engine.EVENT.MESSAGE_MODIFIED, this.onMessageModified, this);
        this.engine.chat.on(this.engine.EVENT.MESSAGE_REVOKED, this.onMessageRevoked, this);
        this.engine.chat.on(this.engine.EVENT.MESSAGE_READ_BY_PEER, this.onMessageReadByPeer, this);
        this.engine.chat.on(this.engine.EVENT.MESSAGE_DOWNLOAD_PROGRESS, this.onMessageDownloadProgress, this);
        this.engine.chat.on(this.engine.EVENT.MESSAGE_READ_RECEIPT_RECEIVED, this.onMessageReadReceiptReceived, this);
        this.engine.chat.on(this.engine.EVENT.MESSAGE_REACTIONS_UPDATED, this.onMessageReactionsUpdated, this);
        this.engine.chat.on(this.engine.EVENT.CONVERSATION_LIST_UPDATED, this.onConversationListUpdated, this);
        this.engine.chat.on(this.engine.EVENT.TOTAL_UNREAD_MESSAGE_COUNT_UPDATED, this.onTotalMessageCountUpdated, this);
        this.engine.chat.on(this.engine.EVENT.PROFILE_UPDATED, this.onProfileUpdated, this);
        this.engine.chat.on(this.engine.EVENT.BLACKLIST_UPDATED, this.onBlacklistUpdated, this);
        this.engine.chat.on(this.engine.EVENT.USER_STATUS_UPDATED, this.onUserStatusUpdated, this);
        this.engine.chat.on(this.engine.EVENT.GROUP_LIST_UPDATED, this.onGroupListUpdated, this);
        this.engine.chat.on(this.engine.EVENT.GROUP_ATTRIBUTES_UPDATED, this.onGroupAttributesUpdated, this);
        this.engine.chat.on(this.engine.EVENT.GROUP_COUNTER_UPDATED, this.onGroupCounterUpdated, this);
        this.engine.chat.on(this.engine.EVENT.FRIEND_LIST_UPDATED, this.onFriendListUpdated, this);
        this.engine.chat.on(this.engine.EVENT.FRIEND_APPLICATION_LIST_UPDATED, this.onFriendApplicationListUpdated, this);
        this.engine.chat.on(this.engine.EVENT.GROUP_SYS_NOTICE, this.onGroupSystemNoticeListUpdated, this);
    };
    EventCenter.prototype.unbindIMEvents = function () {
        this.engine.chat.off(this.engine.EVENT.SDK_READY, this.onSDKReady, this);
        this.engine.chat.off(this.engine.EVENT.SDK_NOT_READY, this.onSDKNotReady, this);
        this.engine.chat.off(this.engine.EVENT.KICKED_OUT, this.onKickedOut, this);
        this.engine.chat.off(this.engine.EVENT.NET_STATE_CHANGE, this.onNetStateChange, this);
        this.engine.chat.off(this.engine.EVENT.MESSAGE_RECEIVED, this.onReceiveMessage, this);
        this.engine.chat.off(this.engine.EVENT.MESSAGE_MODIFIED, this.onMessageModified, this);
        this.engine.chat.off(this.engine.EVENT.MESSAGE_REVOKED, this.onMessageRevoked, this);
        this.engine.chat.off(this.engine.EVENT.MESSAGE_READ_BY_PEER, this.onMessageReadByPeer, this);
        this.engine.chat.off(this.engine.EVENT.MESSAGE_DOWNLOAD_PROGRESS, this.onMessageDownloadProgress, this);
        this.engine.chat.off(this.engine.EVENT.MESSAGE_READ_RECEIPT_RECEIVED, this.onMessageReadReceiptReceived, this);
        this.engine.chat.off(this.engine.EVENT.MESSAGE_REACTIONS_UPDATED, this.onMessageReactionsUpdated, this);
        this.engine.chat.off(this.engine.EVENT.CONVERSATION_LIST_UPDATED, this.onConversationListUpdated, this);
        this.engine.chat.off(this.engine.EVENT.TOTAL_UNREAD_MESSAGE_COUNT_UPDATED, this.onTotalMessageCountUpdated, this);
        this.engine.chat.off(this.engine.EVENT.PROFILE_UPDATED, this.onProfileUpdated, this);
        this.engine.chat.off(this.engine.EVENT.BLACKLIST_UPDATED, this.onBlacklistUpdated, this);
        this.engine.chat.off(this.engine.EVENT.USER_STATUS_UPDATED, this.onUserStatusUpdated, this);
        this.engine.chat.off(this.engine.EVENT.GROUP_LIST_UPDATED, this.onGroupListUpdated, this);
        this.engine.chat.off(this.engine.EVENT.GROUP_ATTRIBUTES_UPDATED, this.onGroupAttributesUpdated, this);
        this.engine.chat.off(this.engine.EVENT.GROUP_COUNTER_UPDATED, this.onGroupCounterUpdated, this);
        this.engine.chat.off(this.engine.EVENT.FRIEND_LIST_UPDATED, this.onFriendListUpdated, this);
        this.engine.chat.off(this.engine.EVENT.FRIEND_APPLICATION_LIST_UPDATED, this.onFriendApplicationListUpdated, this);
        this.engine.chat.off(this.engine.EVENT.GROUP_SYS_NOTICE, this.onGroupSystemNoticeListUpdated, this);
    };
    EventCenter.prototype.onSDKReady = function (event) {
        this.dispatch(this.engine.EVENT.SDK_READY, event.data);
    };
    EventCenter.prototype.onSDKNotReady = function (event) {
        this.dispatch(this.engine.EVENT.SDK_NOT_READY, event.data);
    };
    EventCenter.prototype.onKickedOut = function (event) {
        this.dispatch(this.engine.EVENT.KICKED_OUT, event.data);
    };
    EventCenter.prototype.onNetStateChange = function (event) {
        this.dispatch(this.engine.EVENT.NET_STATE_CHANGE, event.data);
    };
    EventCenter.prototype.onReceiveMessage = function (event) {
        this.dispatch(this.engine.EVENT.MESSAGE_RECEIVED, event.data);
    };
    EventCenter.prototype.onMessageModified = function (event) {
        this.dispatch(this.engine.EVENT.MESSAGE_MODIFIED, event.data);
    };
    EventCenter.prototype.onMessageRevoked = function (event) {
        this.dispatch(this.engine.EVENT.MESSAGE_REVOKED, event.data);
    };
    EventCenter.prototype.onMessageReadByPeer = function (event) {
        this.dispatch(this.engine.EVENT.MESSAGE_READ_BY_PEER, event.data);
    };
    EventCenter.prototype.onMessageDownloadProgress = function (event) {
        this.dispatch(this.engine.EVENT.MESSAGE_DOWNLOAD_PROGRESS, event.data);
    };
    EventCenter.prototype.onMessageReadReceiptReceived = function (event) {
        this.dispatch(this.engine.EVENT.MESSAGE_READ_RECEIPT_RECEIVED, event.data);
    };
    EventCenter.prototype.onMessageReactionsUpdated = function (event) {
        this.dispatch(this.engine.EVENT.MESSAGE_REACTIONS_UPDATED, event.data);
    };
    EventCenter.prototype.onConversationListUpdated = function (event) {
        this.dispatch(this.engine.EVENT.CONVERSATION_LIST_UPDATED, event.data);
    };
    EventCenter.prototype.onTotalMessageCountUpdated = function (event) {
        this.dispatch(this.engine.EVENT.TOTAL_UNREAD_MESSAGE_COUNT_UPDATED, event.data);
    };
    EventCenter.prototype.onProfileUpdated = function (event) {
        this.dispatch(this.engine.EVENT.PROFILE_UPDATED, event.data);
    };
    EventCenter.prototype.onBlacklistUpdated = function (event) {
        this.dispatch(this.engine.EVENT.BLACKLIST_UPDATED, event.data);
    };
    EventCenter.prototype.onUserStatusUpdated = function (event) {
        this.dispatch(this.engine.EVENT.USER_STATUS_UPDATED, event.data);
    };
    EventCenter.prototype.onGroupListUpdated = function (event) {
        this.dispatch(this.engine.EVENT.GROUP_LIST_UPDATED, event.data);
    };
    EventCenter.prototype.onGroupAttributesUpdated = function (event) {
        this.dispatch(this.engine.EVENT.GROUP_ATTRIBUTES_UPDATED, event.data);
    };
    EventCenter.prototype.onGroupCounterUpdated = function (event) {
        this.dispatch(this.engine.EVENT.GROUP_COUNTER_UPDATED, event.data);
    };
    EventCenter.prototype.onFriendListUpdated = function (event) {
        this.dispatch(this.engine.EVENT.FRIEND_LIST_UPDATED, event.data);
    };
    EventCenter.prototype.onFriendApplicationListUpdated = function (event) {
        this.dispatch(this.engine.EVENT.FRIEND_APPLICATION_LIST_UPDATED, event.data);
    };
    EventCenter.prototype.onGroupSystemNoticeListUpdated = function (event) {
        this.dispatch(this.engine.EVENT.GROUP_SYS_NOTICE, event.data);
    };
    EventCenter.instance = undefined;
    return EventCenter;
}());
exports["default"] = EventCenter;
