import TUIBase from '../tui-base';
import type { ITUIFriendService } from '../interface/service';
import type {
  AddFriendParams,
  DeleteFriendParams,
  CheckFriendParams,
  GetFriendProfileParams,
  UpdateFriendParams,
  AcceptFriendApplicationParams,
  DeleteFriendApplicationParams,
  Friend,
} from '../type';
import { StoreName } from '../const';

export default class TUIFriendService extends TUIBase implements ITUIFriendService {
  static instance: TUIFriendService;
  constructor() {
    super();
    console.warn('TUIFriendService instance');
  }

  /**
   * 获取 TUIFriendService 实例
  */
  static getInstance() {
    if (!TUIFriendService.instance) {
      TUIFriendService.instance = new TUIFriendService();
    }
    return TUIFriendService.instance;
  }

  init() {
    const chatEngine = this.getEngine();
    chatEngine.eventCenter.addEvent(chatEngine.EVENT.FRIEND_LIST_UPDATED, this.onFriendListUpdated.bind(this));
    chatEngine.eventCenter.addEvent(chatEngine.EVENT.FRIEND_APPLICATION_LIST_UPDATED, this.onFriendApplicationListUpdated.bind(this));
    this.getFriendInitData();
  }

  private onFriendListUpdated(friendList: Friend[]) {
    const chatEngine = this.getEngine();
    chatEngine.TUIStore.update(StoreName.FRIEND, 'friendList', friendList);
  }

  private onFriendApplicationListUpdated(data: any) {
    const { friendApplicationList, unreadCount = 0 } = data;
    const chatEngine = this.getEngine();
    chatEngine.TUIStore.update(StoreName.FRIEND, 'friendApplicationList', friendApplicationList);
    chatEngine.TUIStore.update(StoreName.FRIEND, 'friendApplicationUnreadCount', unreadCount);
  }

  private getFriendInitData() {
    const chatEngine = this.getEngine();
    if (!chatEngine.chat.isReady()) {
      return;
    }
    chatEngine.chat.getFriendList().then((imResponse: any) => {
      const friendList = imResponse.data || [];
      console.log(`TUIFriendService.init, getFriendList count:${friendList.length}`);
      if (friendList.length > 0) {
        this.onFriendListUpdated(friendList);
      }
    });
    chatEngine.chat.getFriendApplicationList().then((imResponse: any) => {
      this.onFriendApplicationListUpdated(imResponse.data);
    });
  }

  // 暂时留给 engine 内部使用，后续删除此接口
  getFriendList() {
    return this.getEngine().chat.getFriendList();
  }

  getFriendRemark(userIDList: string[]) {
    const chatEngine = this.getEngine();
    const friendList = chatEngine.TUIStore.getData(StoreName.FRIEND, 'friendList');
    const friendRemark: any = {};
    userIDList.forEach((userID: string) => {
      for (let i = 0; i < friendList.length; i++) {
        if (friendList[i].userID === userID) {
          friendRemark[userID] = friendList[i].remark;
          continue;
        }
      }
    });
    return friendRemark;
  }

  addFriend(options: AddFriendParams) {
    return this.getEngine().chat.addFriend(options);
  }

  deleteFriend(options: DeleteFriendParams) {
    return this.getEngine().chat.deleteFriend(options);
  }

  checkFriend(options: CheckFriendParams) {
    return this.getEngine().chat.checkFriend(options);
  }

  getFriendProfile(options: GetFriendProfileParams) {
    return this.getEngine().chat.getFriendProfile(options);
  }

  updateFriend(options: UpdateFriendParams) {
    return this.getEngine().chat.updateFriend(options);
  }

  acceptFriendApplication(options: AcceptFriendApplicationParams) {
    return this.getEngine().chat.acceptFriendApplication(options);
  }

  refuseFriendApplication(userID: string) {
    return this.getEngine().chat.refuseFriendApplication({ userID });
  }

  deleteFriendApplication(options: DeleteFriendApplicationParams) {
    return this.getEngine().chat.deleteFriendApplication(options);
  }

  setFriendApplicationRead() {
    return this.getEngine().chat.setFriendApplicationRead();
  }
}
