"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
exports.__esModule = true;
var conversation_1 = require("../../model/conversation");
var ConversationStore = /** @class */ (function () {
    function ConversationStore() {
        this.defaultStore = {
            currentConversationID: '',
            totalUnreadCount: 0,
            conversationList: [],
            currentConversation: null,
            operationTypeMap: new Map()
        };
        this.store = {
            currentConversationID: '',
            totalUnreadCount: 0,
            conversationList: [],
            currentConversation: null,
            operationTypeMap: new Map()
        };
    }
    ConversationStore.prototype.update = function (key, data) {
        switch (key) {
            case 'conversationList':
                this.updateConversationList(data);
                break;
            case 'operationTypeMap':
                this.updateOperationTypeMap(data);
                break;
            default:
                this.store[key] = data;
        }
    };
    ConversationStore.prototype.getData = function (key) {
        return this.store[key];
    };
    ConversationStore.prototype.getModel = function (conversationID) {
        return this.store.conversationList.find(function (conversation) { return conversation.conversationID === conversationID; });
    };
    ConversationStore.prototype.reset = function (keyList) {
        var _this = this;
        if (keyList === void 0) { keyList = []; }
        this.store = __assign(__assign(__assign({}, this.defaultStore), this.store), keyList.reduce(function (acc, key) {
            var _a;
            return (__assign(__assign({}, acc), (_a = {}, _a[key] = _this.defaultStore[key], _a)));
        }, {}));
    };
    ConversationStore.prototype.updateConversationList = function (list) {
        var _this = this;
        var toBeUpdatedList = [];
        list.forEach(function (item) {
            var conversationModel = item;
            if (!(item instanceof conversation_1["default"])) {
                conversationModel = new conversation_1["default"](item);
            }
            else {
                conversationModel.updateProperties(item);
            }
            var optType = _this.getOperationType(item);
            conversationModel.updateOperationType(optType);
            toBeUpdatedList.push(conversationModel);
        });
        this.store.conversationList = toBeUpdatedList;
    };
    ConversationStore.prototype.updateOperationTypeMap = function (data) {
        var conversationID = data.conversationID, _a = data.operationType, operationType = _a === void 0 ? 0 : _a;
        this.store.operationTypeMap.set(conversationID, operationType);
    };
    ConversationStore.prototype.getOperationType = function (conversation) {
        var conversationID = conversation.conversationID;
        return this.store.operationTypeMap.get(conversationID) || 0;
    };
    return ConversationStore;
}());
exports["default"] = ConversationStore;
