"use strict";
exports.__esModule = true;
var const_1 = require("../const");
var common_utils_1 = require("../utils/common-utils");
var UserProfileHandler = /** @class */ (function () {
    function UserProfileHandler(TUIUserService) {
        this.TUIUserService = TUIUserService;
    }
    UserProfileHandler.prototype.getEngine = function () {
        return this.TUIUserService.getEngine();
    };
    UserProfileHandler.prototype.init = function () {
        this.getEngine().eventCenter.addEvent(this.getEngine().EVENT.PROFILE_UPDATED, this.onProfileUpdated.bind(this));
        this.getEngine().eventCenter.addEvent(this.getEngine().EVENT.BLACKLIST_UPDATED, this.onBlacklistUpdated.bind(this));
        this.getUserProfileInitData();
    };
    UserProfileHandler.prototype.onProfileUpdated = function (userProfileList) {
        var chatEngine = this.getEngine();
        var myProfile = chatEngine.TUIStore.getData(const_1.StoreName.USER, 'userProfile');
        userProfileList.forEach(function (profile) {
            // 自己资料的更新通知需要更新 store 并通知给 UI，好友资料更新通知先不处理
            if (profile.userID === myProfile.userID) {
                chatEngine.TUIStore.update(const_1.StoreName.USER, 'userProfile', profile);
            }
        });
    };
    UserProfileHandler.prototype.onBlacklistUpdated = function (blacklist) {
        var chatEngine = this.getEngine();
        this.getBlacklistProfile(blacklist).then(function (userBlacklist) {
            chatEngine.TUIStore.update(const_1.StoreName.USER, 'userBlacklist', userBlacklist);
        });
    };
    UserProfileHandler.prototype.getUserProfileInitData = function () {
        var _this = this;
        var chatEngine = this.getEngine();
        if (!chatEngine.chat.isReady()) {
            return;
        }
        chatEngine.chat.getBlacklist().then(function (imResponse) {
            var blockList = imResponse.data || [];
            console.log("TUIUserProfileHandler.init, getBlacklist count:" + blockList.length);
            if (blockList.length > 0) {
                _this.onBlacklistUpdated(blockList);
            }
        });
    };
    // 获取黑名单用户资料
    UserProfileHandler.prototype.getBlacklistProfile = function (blacklist) {
        var _this = this;
        // 用户资料一次最大支持查询 100 个用户，需要分组处理
        var blacklistGroup = [];
        var index = 0;
        while (index < blacklist.length) {
            blacklistGroup.push(blacklist.slice(index, index += 100));
        }
        var promiseList = [];
        blacklistGroup.forEach(function (userIDList) {
            promiseList.push(_this.TUIUserService.getUserProfile({ userIDList: userIDList }));
        });
        var userBlacklist = [];
        return Promise.all(promiseList).then(function (imResponseList) {
            imResponseList.forEach(function (imResponse) {
                var filterList = imResponse.data.map(function (profile) {
                    var userID = profile.userID, nick = profile.nick, avatar = profile.avatar;
                    return { userID: userID, nick: nick, avatar: avatar };
                });
                userBlacklist.push.apply(userBlacklist, filterList);
            });
            return userBlacklist;
        });
    };
    UserProfileHandler.prototype.getUserProfile = function (options) {
        var chatEngine = this.getEngine();
        if (common_utils_1.isUndefined(options)) {
            return chatEngine.chat.getMyProfile().then(function (imResponse) {
                chatEngine.TUIStore.update(const_1.StoreName.USER, 'userProfile', imResponse.data);
                return imResponse;
            })["catch"](function (error) { return Promise.reject(error); });
        }
        return chatEngine.chat.getUserProfile(options);
    };
    UserProfileHandler.prototype.updateMyProfile = function (options) {
        return this.getEngine().chat.updateMyProfile(options);
    };
    UserProfileHandler.prototype.addToBlacklist = function (options) {
        return this.getEngine().chat.addToBlacklist(options);
    };
    UserProfileHandler.prototype.removeFromBlacklist = function (options) {
        return this.getEngine().chat.removeFromBlacklist(options);
    };
    return UserProfileHandler;
}());
exports["default"] = UserProfileHandler;
