import type { Message } from '@tencentcloud/chat-react-native';

// message handler 因为需要在 MessageModel 中调用，需要保留声明文件
export interface IMessageHandler {
  /**
   * 处理文本消息
   * @param {Message} message 文本消息
  */
  handleTextMessage(message: Message): object;

  /**
   * 处理表情消息
   * @param {Message} message 表情消息
  */
  handleFaceMessage(message: Message): object;

  /**
   * 处理位置消息
   * @param {Message} message 位置消息
  */
  handleLocationMessage(message: Message): object;

  /**
   * 处理图片消息
   * @param {Message} message 图片消息
  */
  handleImageMessage(message: Message): object;

  /**
   * 处理语音消息
   * @param {Message} message 语音消息
  */
  handleAudioMessage(message: Message): object;

  /**
   * 处理视频消息
   * @param {Message} message 视频消息
  */
  handleVideoMessage(message: Message): object;

  /**
   * 处理文件消息
   * @param {Message} message 文件消息
  */
  handleFileMessage(message: Message): object;

  /**
   * 处理自定义消息
   * @param {Message} message 自定义消息
  */
  handleCustomMessage(message: Message): object;

  /**
   * 处理合并消息
   * @param {Message} message 合并消息
  */
  handleMergeMessage(message: Message): object;

  /**
   * 处理群提示消息
   * @param {Message} message 群 tips 消息
  */
  handleGroupTipsMessage(message: Message): object;

  /**
   * 处理群系统消息
   * @param {Message} message 群系统消息
  */
  handleGroupSystemMessage(message: Message): object;

  /**
   * 处理音视频通话信令
   * @param {any} message 会话最后一条消息或漫游消息
  */
  handleCallKitSignaling(message: any): string | undefined;
}
