/**
 * @interface TUITranslateService
*/
export interface ITUITranslateService {

  /**
   * 设置本地语言包
   * @function
   * @param {object} languages 语言包资源
   * @example
   * TUITranslateService.provideLanguages(languages);
   */
  provideLanguages(languages: object): void;

  /**
   * 初始化 i8next
   * @function
   * @param {string} [language] 目标语言，默认目标语言是中文 'zh'
   * @example
   * // 设置目标语言为英语
   * TUITranslateService.useI18n('en');
   */
  useI18n(language?: string): void;

  /**
   * 切换语言
   * @function
   * @param {string} language 目标语言
   * @example
   * // 切换为英语
   * TUITranslateService.changeLanguage('en').then(() => {
   *    // 语言切换成功后处理业务
   * });
   */
  changeLanguage(language: string): Promise<any>;

  /**
   * 翻译文本
   * @function
   * @param {string} key 待翻译的数据
   * @example
   * // 翻译为目标语言
   * let text = TUITranslateService.t('TUIChat.撤回');
   */
  t(key: string): string;
}
